@@ -77,7 +77,6 @@ typedef enum
   WNCK_WINDOW_DESKTOP,      /* desktop background */
   WNCK_WINDOW_DOCK,         /* panel */
   WNCK_WINDOW_DIALOG,       /* dialog */
-  WNCK_WINDOW_MODAL_DIALOG, /* modal dialog */
   WNCK_WINDOW_TOOLBAR,      /* tearoff toolbar */
   WNCK_WINDOW_MENU,         /* tearoff menu */
   WNCK_WINDOW_UTILITY,      /* palette/toolbox window */
@@ -151,6 +150,12 @@ struct _WnckWindowClass
 
   /* Changed size/position */
   void (* geometry_changed)      (WnckWindow       *window);
+  
+  /* Padding for future expansion */
+  void (* pad1) (void);
+  void (* pad2) (void);
+  void (* pad3) (void);
+  void (* pad4) (void);
 };
 
 GType wnck_window_get_type (void) G_GNUC_CONST;
