@@ -22,6 +22,10 @@ GType wnck_window_actions_get_type (void);
 #define WNCK_TYPE_WINDOW_ACTIONS (wnck_window_actions_get_type())
 GType wnck_window_type_get_type (void);
 #define WNCK_TYPE_WINDOW_TYPE (wnck_window_type_get_type())
+GType wnck_window_gravity_get_type (void);
+#define WNCK_TYPE_WINDOW_GRAVITY (wnck_window_gravity_get_type())
+GType wnck_window_move_resize_mask_get_type (void);
+#define WNCK_TYPE_WINDOW_MOVE_RESIZE_MASK (wnck_window_move_resize_mask_get_type())
 #endif /* __WNCK_ENUM_TYPES_H__ */
 
 /* Generated data ends here */
